<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Trivia Animación Digital</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&display=swap">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        :root {
            --primary-color: rgb(130, 165, 235);
            --secondary-color: rgb(248, 104, 20);
            --correct-color: #4caf50;
            --incorrect-color: #f44336;
            --white: #fff;
            --text-color: #333;
        }

        body {
            font-family: 'Roboto', sans-serif;
            margin: 0;
            padding: 0;
            background-color: var(--primary-color);
            color: var(--text-color);
            display: flex;
            flex-direction: column;
            min-height: 100vh;
        }

        header {
            background-color: var(--primary-color);
            color: var(--white);
            width: 100%;
            padding: 20px;
            text-align: center;
            box-sizing: border-box;
        }
                /* Título principal */
        .main-title {
            font-size: 3rem;
            font-weight: bold;
            color: #ff6600; /* Naranja */
            text-shadow: 0 2px 4px rgba(255, 255, 255, 0.8), 0 0 10px rgba(255, 102, 0, 0.8);
            margin-bottom: 5px;
        }

        .logo {
            margin: 0;
            font-size: 2.5rem;
            font-weight: 700;
            background: linear-gradient(90deg, #ff8a00, #e52e71);
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
            text-shadow: 0 0 10px rgba(255, 255, 255, 0.5);
            animation: glow 2s ease-in-out infinite alternate;
        }

        @keyframes glow {
            0% { text-shadow: 0 0 10px rgba(255, 255, 255, 0.5), 0 0 20px rgba(255, 138, 0, 0.5); }
            100% { text-shadow: 0 0 20px rgba(255, 255, 255, 0.8), 0 0 30px rgba(229, 46, 113, 0.8); }
        }

        .nav-links {
            display: flex;
            justify-content: center;
            gap: 20px;
            margin-top: 10px;
        }

        .nav-links a {
            text-decoration: none;
            background-color: var(--secondary-color);
            color: var(--white);
            padding: 8px 15px;
            border-radius: 5px;
            font-size: 1rem;
            font-weight: bold;
            transition: all 0.3s ease;
            border: 3px solid var(--white);
        }

        .nav-links a:hover {
            background-color: var(--white);
            color: var(--primary-color);
            transform: scale(1.05);
        }

        .trivia-title {
            font-size: 2rem;
            color: var(--white);
            background-color: rgb(27 60 231);
            padding: 10px 20px;
            border-radius: 5px;
            margin: 20px 0;
            text-align: center;
            border: 3px solid var(--white);
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.2);
        }

        main {
            flex-grow: 1;
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
            padding: 20px;
            width: 100%;
        }

        #quiz-container {
            width: 100%;
            max-width: 600px;
        }

        .question {
            border: 3px solid var(--white);
            background: rgba(255, 255, 255, 0.2);
            padding: 20px;
            margin-bottom: 20px;
            border-radius: 10px;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.2);
            text-align: center;
        }

        .question h2 {
            margin: 0 0 15px 0;
            font-size: 1.5rem;
        }

        .options {
            list-style-type: none;
            padding: 0;
            margin: 0;
        }

        .options li {
            margin: 10px 0;
        }

        button {
            background-color: var(--secondary-color);
            color: var(--white);
            border: 3px solid var(--white);
            padding: 10px 20px;
            border-radius: 5px;
            font-size: 1rem;
            cursor: pointer;
            transition: all 0.3s ease;
            width: 100%;
        }

        button:hover:not(:disabled) {
            background-color: var(--primary-color);
            transform: scale(1.02);
        }

        button:disabled {
            opacity: 0.7;
            cursor: not-allowed;
        }

        #next-button {
            margin-top: 20px;
            display: block;
            margin-left: auto;
            margin-right: auto;
            max-width: 200px;
        }

        #result {
            text-align: center;
            margin-top: 20px;
            width: 100%;
            max-width: 600px;
            background: rgba(255, 255, 255, 0.2);
            padding: 20px;
            border-radius: 10px;
            border: 3px solid var(--white);
        }

        .back-button {
            display: block;
            margin: 20px auto;
            background-color: var(--secondary-color);
            color: var(--white);
            border: 3px solid var(--white);
            padding: 10px 20px;
            border-radius: 5px;
            font-size: 1rem;
            font-weight: bold;
            text-decoration: none;
            transition: all 0.3s ease;
            text-align: center;
            max-width: 200px;
        }

        .back-button:hover {
            background-color: var(--primary-color);
            transform: scale(1.05);
        }

        footer {
            background-color: var(--primary-color);
            color: var(--white);
            text-align: center;
            padding: 10px;
            width: 100%;
            border-top: 3px solid var(--white);
            box-sizing: border-box;
        }

        .correct {
            background-color: var(--correct-color) !important;
        }

        .incorrect {
            background-color: var(--incorrect-color) !important;
        }

        .timer-container {
            margin: 10px 0;
            text-align: center;
        }

        .timer {
            font-size: 1.5rem;
            font-weight: bold;
            color: var(--white);
            background-color: var(--secondary-color);
            padding: 5px 15px;
            border-radius: 50%;
            border: 3px solid var(--white);
            display: inline-block;
        }

        .time-warning {
            animation: pulse 0.5s infinite alternate;
        }

        @keyframes pulse {
            from { transform: scale(1); }
            to { transform: scale(1.1); background-color: var(--incorrect-color); }
        }

        .result-details {
            margin-top: 20px;
            text-align: left;
        }

        .result-item {
            margin-bottom: 15px;
            padding: 10px;
            background: rgba(255, 255, 255, 0.1);
            border-radius: 5px;
        }

        .result-correct {
            border-left: 5px solid var(--correct-color);
        }

        .result-incorrect {
            border-left: 5px solid var(--incorrect-color);
        }

        @media (max-width: 768px) {
            .logo {
                font-size: 2rem;
            }

            .nav-links {
                flex-direction: column;
                gap: 10px;
            }

            .nav-links a {
                width: 200px;
                margin: 0 auto;
            }

            .trivia-title {
                font-size: 1.5rem;
            }

            main {
                padding: 10px;
            }

            .question {
                padding: 15px;
            }

            button, .back-button {
                max-width: 200px;
            }
        }

        .slogan {
            font-size: 1.2rem;
            color: white;
            font-weight: bold;
        }
    </style>
</head>
<body>
    <header>
    <!-- Título principal -->
        <h1 class="main-title">💭Quiztudio🎓</h1>
        <p class="slogan">📚Aprende jugando📝</p> 
        <div class="nav-links">
            <a href="pagina_principal.php">Inicio</a>
            <a href="RegistrarUsuario.php">Registrar Usuario</a>
            <a href="cerrar_sesion.php">Cerrar Sesión</a>
        </div>
    </header>
    <main>
        <div class="trivia-title">Trivia de Animación Digital</div>
        <div id="quiz-container"></div>
        <button id="next-button" style="display:none">Siguiente</button>
        <div id="result" style="display:none;">
            <h2>Resultados Finales</h2>
            <p id="score"></p>
            <div id="feedback"></div>
            <div id="result-details" class="result-details"></div>
        </div>
        <a href="pagina_principal.php" class="back-button">Regresar a Inicio</a>
    </main>
    <footer>
        © 2025 Quiztudio. Todos los derechos reservados.
    </footer>

    <script>
        const questions = [
            {
                question: "¿Qué software es ampliamente usado para animación 2D?",
                options: ["Blender", "Toon Boom Harmony", "Cinema 4D", "Autodesk Maya"],
                correct: 1,
                explanation: "Toon Boom Harmony es una herramienta líder para animación 2D, utilizada en producciones profesionales."
            },
            {
                question: "¿Qué técnica de animación utiliza fotogramas clave?",
                options: ["Stop Motion", "Keyframing", "Rotoscopia", "Motion Capture"],
                correct: 1,
                explanation: "Keyframing implica definir fotogramas clave y dejar que el software interpole los movimientos intermedios."
            },
            {
                question: "¿Qué es el 'rigging' en animación 3D?",
                options: ["Crear texturas", "Añadir efectos de luz", "Construir un esqueleto para el modelo", "Renderizar la escena"],
                correct: 2,
                explanation: "El 'rigging' es el proceso de crear un esqueleto digital para que un modelo 3D pueda ser animado."
            },
            {
                question: "¿Qué significa FPS en animación?",
                options: ["Frames Per Second", "Files Per Scene", "Functions Per Second", "Frames Per Scale"],
                correct: 0,
                explanation: "FPS (Frames Per Second) indica la cantidad de fotogramas por segundo, afectando la fluidez de la animación."
            },
            {
                question: "¿Qué software es conocido por animación y modelado 3D?",
                options: ["After Effects", "Blender", "Premiere Pro", "Illustrator"],
                correct: 1,
                explanation: "Blender es un software gratuito y de código abierto muy utilizado para animación y modelado 3D."
            },
            {
                question: "¿Qué técnica usa objetos físicos para crear animación?",
                options: ["Stop Motion", "CGI", "Keyframing", "Motion Graphics"],
                correct: 0,
                explanation: "Stop Motion utiliza objetos físicos fotografiados en diferentes posiciones para simular movimiento."
            },
            {
                question: "¿Qué es el 'rendering' en animación?",
                options: ["Dibujar los bocetos", "Generar la imagen final", "Crear el storyboard", "Añadir sonido"],
                correct: 1,
                explanation: "El 'rendering' es el proceso de generar la imagen o video final a partir de los datos de la escena."
            },
            {
                question: "¿Qué principio de animación exagera movimientos para dar énfasis?",
                options: ["Squash and Stretch", "Exaggeration", "Timing", "Staging"],
                correct: 1,
                explanation: "La 'exaggeration' exagera movimientos o expresiones para hacer la animación más expresiva."
            },
            {
                question: "¿Qué formato de archivo es común para animaciones con transparencia?",
                options: ["MP4", "MOV", "GIF", "AVI"],
                correct: 2,
                explanation: "GIF es un formato popular para animaciones cortas con soporte para transparencia binaria."
            },
            {
                question: "¿Qué herramienta de Adobe se usa para motion graphics?",
                options: ["Photoshop", "Illustrator", "After Effects", "InDesign"],
                correct: 2,
                explanation: "After Effects es el estándar de Adobe para crear motion graphics y efectos visuales."
            }
        ];

        let currentQuestionIndex = 0;
        let score = 0;
        let timer;
        let timeLeft = 15;
        let userAnswers = [];

        const quizContainer = document.getElementById('quiz-container');
        const nextButton = document.getElementById('next-button');
        const resultContainer = document.getElementById('result');
        const scoreText = document.getElementById('score');
        const feedbackContainer = document.getElementById('feedback');
        const resultDetailsContainer = document.getElementById('result-details');

        function showQuestion() {
            timeLeft = 15;
            clearInterval(timer);
            
            const currentQuestion = questions[currentQuestionIndex];
            quizContainer.innerHTML = `
                <div class="question">
                    <h2>${currentQuestion.question}</h2>
                    <div class="timer-container">
                        <div class="timer" id="timer">${timeLeft}</div>
                    </div>
                    <ul class="options">
                        ${currentQuestion.options.map((option, index) => `
                            <li><button class="option-btn" data-index="${index}">${option}</button></li>
                        `).join('')}
                    </ul>
                </div>
            `;
            
            nextButton.style.display = 'none';
            feedbackContainer.innerHTML = '';
            addOptionListeners();
            startTimer();
        }

        function startTimer() {
            const timerElement = document.getElementById('timer');
            
            timer = setInterval(() => {
                timeLeft--;
                timerElement.textContent = timeLeft;
                
                if (timeLeft <= 5) {
                    timerElement.classList.add('time-warning');
                }
                
                if (timeLeft <= 0) {
                    clearInterval(timer);
                    timeUp();
                }
            }, 1000);
        }

        function timeUp() {
            const currentQuestion = questions[currentQuestionIndex];
            const optionButtons = document.querySelectorAll('.option-btn');
            
            userAnswers.push({
                question: currentQuestion.question,
                userAnswer: null,
                correctAnswer: currentQuestion.options[currentQuestion.correct],
                explanation: currentQuestion.explanation,
                isCorrect: false,
                timeUp: true
            });
            
            optionButtons.forEach((button, index) => {
                button.disabled = true;
                if (index === currentQuestion.correct) {
                    button.classList.add('correct');
                }
            });
            
            feedbackContainer.innerHTML = `
                <p>¡Tiempo agotado! La respuesta correcta era: <strong>${currentQuestion.options[currentQuestion.correct]}</strong></p>
                <p>${currentQuestion.explanation}</p>
            `;
            nextButton.style.display = 'block';
        }

        function checkAnswer(selectedIndex) {
            clearInterval(timer);
            const currentQuestion = questions[currentQuestionIndex];
            const optionButtons = document.querySelectorAll('.option-btn');
            const timerElement = document.getElementById('timer');
            
            if (timerElement) {
                timerElement.classList.remove('time-warning');
            }

            const isCorrect = selectedIndex === currentQuestion.correct;
            userAnswers.push({
                question: currentQuestion.question,
                userAnswer: currentQuestion.options[selectedIndex],
                correctAnswer: currentQuestion.options[currentQuestion.correct],
                explanation: currentQuestion.explanation,
                isCorrect: isCorrect,
                timeUp: false
            });

            if (isCorrect) {
                score++;
            }

            optionButtons.forEach((button, index) => {
                button.disabled = true;
                if (index === currentQuestion.correct) {
                    button.classList.add('correct');
                } else if (index === selectedIndex) {
                    button.classList.add('incorrect');
                }
            });

            feedbackContainer.innerHTML = isCorrect ? 
                `<p>¡Correcto! ${currentQuestion.explanation}</p>` :
                `<p>Incorrecto. La respuesta correcta es: <strong>${currentQuestion.options[currentQuestion.correct]}</strong></p>
                 <p>${currentQuestion.explanation}</p>`;

            nextButton.style.display = 'block';
        }

        function addOptionListeners() {
            document.querySelectorAll('.option-btn').forEach(button => {
                button.addEventListener('click', (e) => {
                    const selectedIndex = parseInt(e.target.getAttribute('data-index'));
                    checkAnswer(selectedIndex);
                });
            });
        }

        function showResults() {
            quizContainer.style.display = 'none';
            nextButton.style.display = 'none';
            resultContainer.style.display = 'block';
            
            const percentage = Math.round((score / questions.length) * 100);
            scoreText.textContent = `Tu puntaje es ${score} de ${questions.length} (${percentage}%)`;
            
            if (percentage >= 80) {
                feedbackContainer.innerHTML += "<p>¡Excelente! Dominas los conceptos de animación digital.</p>";
            } else if (percentage >= 50) {
                feedbackContainer.innerHTML += "<p>Buen trabajo, pero hay áreas que podrías reforzar.</p>";
            } else {
                feedbackContainer.innerHTML += "<p>Sigue aprendiendo, la animación es un campo emocionante.</p>";
            }

            showDetailedResults();
        }

        function showDetailedResults() {
            let detailsHTML = '<h3>Detalle de respuestas:</h3>';
            
            userAnswers.forEach((answer, index) => {
                const resultClass = answer.isCorrect ? 'result-correct' : 'result-incorrect';
                
                detailsHTML += `
                    <div class="result-item ${resultClass}">
                        <p><strong>Pregunta ${index + 1}:</strong> ${answer.question}</p>
                        ${answer.timeUp ? 
                            '<p>⏰ No respondiste a tiempo</p>' : 
                            `<p>Tu respuesta: ${answer.userAnswer}</p>`
                        }
                        <p>Respuesta correcta: ${answer.correctAnswer}</p>
                        <p>Explicación: ${answer.explanation}</p>
                    </div>
                `;
            });
            
            resultDetailsContainer.innerHTML = detailsHTML;
        }

        nextButton.addEventListener('click', () => {
            currentQuestionIndex++;
            if (currentQuestionIndex < questions.length) {
                showQuestion();
            } else {
                showResults();
            }
        });

        showQuestion();
    </script>
</body>
</html>